@@ -1,10 +1,10 @@
-# $Id: SQLite.pm 58 2018-08-03 20:06:35Z stro $
+# $Id: SQLite.pm 69 2019-01-04 00:24:35Z stro $
 
 package CPAN::SQLite;
 use strict;
 use warnings;
 
-our $VERSION = '0.212';
+our $VERSION = '0.213';
 
 use English qw/-no_match_vars/;
 
@@ -98,7 +98,7 @@ CPAN::SQLite - maintain and search a minimal CPAN database
 
 =head1 VERSION
 
-version 0.212
+version 0.213
 
 =head1 SYNOPSIS
 
@@ -257,16 +257,11 @@ directory as the database file.
 
 =head1 SEE ALSO
 
-L<CPAN::SQLite::Index>, for setting up and maintaining
-the database, and L<CPAN::SQLite::Search> for an
-interface to querying the database. Some details
-of the interaction with L<CPAN> is available from
-L<CPAN::SQLite::META>. See also the L<cpandb> script for a
-command-line interface to the
-indexing and querying of the database.
-
-Development takes place on the CPAN-Search-Lite project
-at L<http://cpan-search.svn.sourceforge.net/viewvc/cpan-search/CPAN-SQLite/>.
+L<CPAN::SQLite::Index>, for setting up and maintaining the database, and
+L<CPAN::SQLite::Search> for an interface to querying the database. Some
+details of the interaction with L<CPAN> is available from
+L<CPAN::SQLite::META>. See also the L<cpandb> script for a command-line
+interface to the indexing and querying of the database.
 
 =head1 SUPPORT
 
@@ -325,6 +320,15 @@ during the indexing procedures. Log files are deleted automatically
 in 30 days. To override this, set CPAN_SQLITE_LOG_FILES_CLEANUP.
 To stop automatic cleanup, set this variable to 0.
 
+If CPAN_SQLITE_DOWNLOAD variable are set, an already existing and
+up-to-date cpandb.sql file will be downloaded from
+http://cpansqlite.trouchelle.com/ where it's updated every hour. This
+greatly increases performance and decreases CPU and memory consumption
+during the indexing process.
+
+See L<CPAN::SQLite::Index> for more details, potential problems, and more
+configuration options.
+
 =head1 AUTHORS
 
 Randy Kobes (passed away on September 18, 2010)
