@@ -1,10 +1,10 @@
-# $Id: Index.pm 58 2018-08-03 20:06:35Z stro $
+# $Id: Index.pm 69 2019-01-04 00:24:35Z stro $
 
 package CPAN::SQLite::Index;
 use strict;
 use warnings;
 
-our $VERSION = '0.212';
+our $VERSION = '0.213';
 
 use English qw/-no_match_vars/;
 
@@ -17,6 +17,8 @@ use File::Basename;
 use File::Path;
 use HTTP::Tiny;
 
+use Scalar::Util 'weaken';
+
 unless ($ENV{CPAN_SQLITE_NO_LOG_FILES}) {
   $ENV{CPAN_SQLITE_DEBUG} = 1;
 }
@@ -24,6 +26,7 @@ unless ($ENV{CPAN_SQLITE_NO_LOG_FILES}) {
 our ($oldout);
 my $log_file = 'cpan_sqlite_log.' . time;
 
+
 # This is usually already defined in real life, but tests need it to be set
 $CPAN::FrontEnd ||= "CPAN::Shell";
 
@@ -37,6 +40,31 @@ sub new {
   return bless $self, $class;
 }
 
+sub download_index {
+  my $self = shift;
+
+  if ($ENV{'CPAN_SQLITE_DOWNLOAD'}) {
+    $ENV{'CPAN_SQLITE_DOWNLOAD_URL'} = 'http://cpansqlite.trouchelle.com/' unless $ENV{'CPAN_SQLITE_DOWNLOAD_URL'};
+  }
+
+  return 0 unless $ENV{'CPAN_SQLITE_DOWNLOAD_URL'};
+
+  $CPAN::FrontEnd->myprint("Downloading the compiled index db ... ");
+
+  if (my $response = HTTP::Tiny->new->mirror($ENV{'CPAN_SQLITE_DOWNLOAD_URL'} => catfile($self->{'db_dir'}, $self->{'db_name'}))) {
+    if ($response->{'success'} and $response->{'status'} and $response->{'status'} eq '200') {
+      if (my $type = $response->{'headers'}->{'content-type'}) {
+        if ($type eq 'application/x-sqlite3') {
+          return 1;
+        }
+      }
+    }
+  }
+
+  $CPAN::FrontEnd->mywarn('Cannot download the compiled index db');
+  return 0;
+}
+
 sub index {
     my $self = shift;
     my $setup = $self->{'setup'};
@@ -76,6 +104,10 @@ sub index {
       }
     }
 
+    if ($self->download_index()) {
+        return 1;
+    }
+
     if ($self->{'update_indices'}) {
         $CPAN::FrontEnd->myprint('Fetching index files ... ');
         if ($self->fetch_cpan_indices()) {
@@ -216,7 +248,7 @@ CPAN::SQLite::Index - set up or update database tables.
 
 =head1 VERSION
 
-version 0.212
+version 0.213
 
 =head1 SYNOPSIS
 
@@ -264,7 +296,22 @@ are not captured, and will appear in I<STDERR>.
 
 The steps of the indexing procedure are as follows.
 
-=over 3
+=over 4
+
+=item * download existing pre-compiled index (optional)
+
+If CPAN_SQLITE_DOWNLOAD or CPAN_SQLITE_DOWNLOAD_URL variables are set, an
+already existing and up-to-date cpandb.sql file will be downloaded from
+either specified URL or http://cpansqlite.trouchelle.com/ where it's
+updated every hour. This greatly increases performance and decreases CPU
+and memory consumption during the indexing process but if your CPAN
+mirror is out-of-sync or you're using DarkPAN, it obviously wouldn't
+work. It also wouldn't work without an internet connection.
+
+See L<WWW::CPAN::SQLite> if you want to setup your own service for
+pre-compiling the database.
+
+If neither variable is set, this step is skipped.
 
 =item * fetch index data
 
